/* 
 * Copyright 2019, Emanuel Rabina (http://www.ultraq.net.nz/)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import {promisify} from '../../source/utilities/Functions.js';

/**
 * Tests for the function utilities.
 */
describe('utilities/Functions', function() {

	describe('#promisify', function() {

		test('Promise maps success to the `then` handler', async function() {
			let promisifiedFunc = promisify((callback) => {
				callback(false, 'Hello!');
			});
			await expect(promisifiedFunc()).resolves.toBe('Hello!');
		});

		test('Promise maps failure to the `catch` handler', async function() {
			let promisifiedFunc = promisify((callback) => {
				callback(true, 'Goodbye!');
			});
			await expect(promisifiedFunc()).rejects.toThrow('Goodbye!');
		});
	});
});
